@@ -19,12 +19,14 @@
 #include <QQmlContext>
 {%- endif %}
 #include <QSettings>
+#include <QSharedMemory>
 #include <QTextCodec>
 #include <QTimer>
 #include <iostream>
 {%- if template==".gui" %}
 #include "widget.h"
 {%- endif %}
+#include"debug_tools/crash_stack.h"
 
 void logMessageHandler(QtMsgType type, const QMessageLogContext &context, const QString &msg) {
     QString logLevel;
@@ -72,6 +74,18 @@ void logMessageHandler(QtMsgType type, const QMessageLogContext &context, const
 
 
 int main(int argc, char *argv[]) {
+#ifdef Q_OS_WIN
+    SetUnhandledExceptionFilter(CrashHandler);
+#endif
+
+    // ONLY ALLOW SINGLETON!
+    //    QSharedMemory shared("immigration_office_qml_app");
+    //    if (shared.attach()) {
+    //        qCritical() << "app: multiple instances are not allowed";
+    //        return 0;
+    //    }
+    //    shared.create(1);
+
 {%- if template!=".console" %}
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0))
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
